@@ -4,11 +4,17 @@ Examples for ReportReader
 
 from secfsdstools.e_read.reportreading import ReportReader
 
-if __name__ == '__main__':
-    # id apples 10k report from september 2022
-    ADSH_APPLE_10K_2022: str = '0000320193-22-000108'
 
-    apple_10k_2022_reader = ReportReader.get_report_by_adsh(adsh=ADSH_APPLE_10K_2022)
+def run():
+    # pylint: disable=W0612
+    """
+    run the example
+    """
+
+    # id apples 10k report from september 2022
+    adsh_apple_10k_2022: str = '0000320193-22-000108'
+
+    apple_10k_2022_reader = ReportReader.get_report_by_adsh(adsh=adsh_apple_10k_2022)
 
     # reading the raw content of the num and pre files
     raw_pre_df = apple_10k_2022_reader.get_raw_pre_data()
@@ -30,3 +36,7 @@ if __name__ == '__main__':
     # Filter for CashFlow
     apple_10k_2022_cf_df = apple_10k_2022_current_and_previous_year_df[
         apple_10k_2022_current_and_previous_year_df.stmt == 'CF']
+
+
+if __name__ == '__main__':
+    run()
